if( not QoreysBB ) then return end

local Extras = QoreysBB:NewModule("Extras", "AceEvent-3.0")
local L = QoreysBBLocals
local units = {["target"] = true, ["focus"] = true, ["pet"] = true}
local groups = {"targetbuffs", "targetdebuffs", "focusbuffs", "focusdebuffs", "petbuffs", "petdebuffs"}

function Extras:OnInitialize()
	if( QoreysBB.db.profile.showExtras ) then
		self:Enable()
	end
end

function Extras:UNIT_AURA(event, unit)
	if( not units[unit] ) then
		return
	end
	
	QoreysBB:UpdateAuras(unit .. "buffs", unit, "HELPFUL")
	QoreysBB:UpdateDisplay(unit .. "buffs")

	QoreysBB:UpdateAuras(unit .. "debuffs", unit, "HARMFUL")
	QoreysBB:UpdateDisplay(unit .. "debuffs")
end

function Extras:PLAYER_TARGET_CHANGED()
	self:UNIT_AURA(nil, "target")
end

function Extras:PLAYER_PET_CHANGED()
	self:UNIT_AURA(nil, "pet")
end

function Extras:PLAYER_FOCUS_CHANGED()
	self:UNIT_AURA(nil, "focus")
end

-- Managing if it's enabled/disabled/etc
function Extras:Enable()
	if( self.enabled ) then
		return
	end
	
	self.enabled = true
	
	-- Create DB defaults
	for _, key in pairs(groups) do
		if( not QoreysBB.db.profile.groups[key] ) then
			QoreysBB.db.profile.groups[key] = CopyTable(QoreysBB.defaults.profile.anchors)
			QoreysBB.db.profile.groups[key].enabled = false
			QoreysBB.db.profile.groups[key].name = L[key]
		end
	end
	
	-- Create groups
	QoreysBB:UpdateGroups()
	
	-- Create configuration
	self:CreateConfiguration()
	
	-- Update auras
	for unit in pairs(units) do
		self:UNIT_AURA(nil, unit)
	end
	
	-- Register events
	self:RegisterEvent("UNIT_AURA")
	self:RegisterEvent("PLAYER_TARGET_CHANGED")
	self:RegisterEvent("PLAYER_PET_CHANGED")
	self:RegisterEvent("PLAYER_FOCUS_CHANGED")
end

function Extras:Disable()
	if( not self.enabled ) then
		return
	end
	
	self.enabled = nil
	
	-- Reset DB data
	for _, key in pairs(groups) do
		QoreysBB.db.profile.groups[key] = nil
		QoreysBB.groups[key]:Hide()
		
		if( QoreysBB.modules.Config.options ) then
			QoreysBB.modules.Config.options.args[key] = nil
		end
	end
		
	-- Unregister all events so it stops updating
	self:UnregisterAllEvents()
end


function Extras:Reload()
	if( QoreysBB.db.profile.showExtras ) then
		if( self.enabled ) then
			-- Update auras
			for unit in pairs(units) do
				self:UNIT_AURA(nil, unit)
			end
		end

		self:Enable()
	else
		self:Disable()
	end
end

-- Creates the configuration for these
function Extras:CreateConfiguration()
	if( not QoreysBB.db.profile.showExtras or not QoreysBB.modules.Config.options ) then
		return
	end
	
	local Config = QoreysBB.modules.Config
	for _, key in pairs(groups) do
		if( not Config.options.args[key] ) then
			Config.options.args[key] = Config:CreateGroupConfig(key, L[key])
		end
	end
end

